## [1.1.0](https://github.com/ScrapeGraphAI/Scrapontologies/compare/v1.0.0...v1.1.0) (2024-10-15)


### Features

* added support for multiple llms ([89f4683](https://github.com/ScrapeGraphAI/Scrapontologies/commit/89f46831365a1cd88cc84b7b76e1a5e7dd457f6c))
